@@ -1,6 +1,5 @@
 import asyncio
 import logging
-from typing import Any
 
 from discord.ext import commands
 
@@ -19,7 +18,7 @@ class SeriesCog(commands.Cog):
 
     @commands.command(name="addshow", help="add a show to the plex")
     @commands.has_any_role("plex-admin", "plex-shows")
-    async def addshow_cmd(self, ctx: commands.Context[Any], *, query: str = "") -> None:
+    async def addshow_cmd(self, ctx: commands.Context[commands.Bot], *, query: str = "") -> None:
         if not query:
             await reply(ctx.message, "usage: !addshow KEYWORDS...")
             return
@@ -91,7 +90,9 @@ class SeriesCog(commands.Cog):
 
     @commands.command(name="delshow", help="delete a show from the plex")
     @commands.has_any_role("plex-admin", "plex-shows")
-    async def delshow_command(self, ctx: commands.Context[Any], *, query: str = "") -> None:
+    async def delshow_command(
+        self, ctx: commands.Context[commands.Bot], *, query: str = ""
+    ) -> None:
         if not query:
             await reply(ctx.message, "usage: !delshow KEYWORDS...")
             return
