@@ -4,15 +4,15 @@ import re
 import shlex
 import shutil
 import subprocess
+import tempfile
 import threading
-from datetime import timedelta
 from time import sleep
-from typing import Any
 
 from wi1_bot import push
 from wi1_bot.arr import Radarr, Sonarr, replace_remote_paths
 from wi1_bot.config import config
 
+from .ffprobe import FfprobeException, ffprobe
 from .transcode_queue import TranscodeItem, queue
 
 # https://github.com/Radarr/Radarr/blob/e29be26fc9a5570bdf37a1b9504b3c0162be7715/src/NzbDrone.Core/Parser/Parser.cs#L134
@@ -32,6 +32,89 @@ class UnknownError(Exception):
     pass
 
 
+def build_ffmpeg_command(item: TranscodeItem, transcode_to: pathlib.Path | str) -> list[str]:
+    command = [
+        "ffmpeg",
+        "-hide_banner",
+        "-y",
+    ]
+
+    if "transcoding" in config and "hwaccel" in config["transcoding"]:
+        command.extend(["-hwaccel", config["transcoding"]["hwaccel"]])
+        command.extend(["-hwaccel_output_format", config["transcoding"]["hwaccel"]])
+
+    command.extend(["-probesize", "100M"])
+    command.extend(["-analyzeduration", "250M"])
+
+    command.extend(["-i", item.path])
+
+    langs: list[str] = []
+
+    if item.languages:
+        langs = [lang.strip() for lang in item.languages.split(",")]
+
+    info = ffprobe(item.path)
+    streams = info["streams"]
+
+    command.extend(["-map", "0:v:0"])
+
+    if item.video_params:
+        params = shlex.split(item.video_params)
+
+        for param in params:
+            if param.startswith("-"):
+                command.append(f"{param}:v:0")
+            else:
+                command.append(param)
+    else:
+        command.extend(["-c:v:0", "copy"])
+
+    command.extend(["-map", "0:a:0?"])
+
+    if item.audio_params:
+        params = shlex.split(item.audio_params)
+
+        for param in params:
+            if param.startswith("-"):
+                command.append(f"{param}:a:0")
+            else:
+                command.append(param)
+    else:
+        command.extend(["-c:a:0", "copy"])
+
+    first_video = True
+    vindex = 1
+    sindex = 0
+
+    for stream in streams:
+        if stream["codec_type"] == "video":
+            if first_video:
+                first_video = False
+                continue
+
+            command.extend(["-map", f"0:{stream['index']}"])
+            command.extend([f"-c:v:{vindex}", "copy"])
+            vindex += 1
+        elif stream["codec_type"] == "subtitle":
+            if langs and (
+                "language" not in stream["tags"] or stream["tags"]["language"] not in langs
+            ):
+                continue
+
+            command.extend(["-map", f"0:{stream['index']}"])
+
+            codec = "copy"
+            if "codec_name" in stream and stream["codec_name"] == "mov_text":
+                codec = "subrip"
+            command.extend([f"-c:s:{sindex}", codec])
+
+            sindex += 1
+
+    command.extend([str(transcode_to)])
+
+    return command
+
+
 class Transcoder:
     def __init__(self) -> None:
         self.logger = logging.getLogger(__name__)
@@ -54,17 +137,28 @@ class Transcoder:
                 sleep(3)
                 continue
 
-            try:
-                remove = self._do_transcode(item)
+            remove = False
 
-                if remove:
-                    queue.remove(item)
+            try:
+                remove = self.transcode(item)
+            except FfprobeException:
+                self.logger.warning("ffprobe failed, will not retry", exc_info=True)
+                push.send(
+                    f"{item.path} has failed to transcode due to ffprobe error",
+                    title="transcoding error",
+                )
+                remove = True
             except Exception:
-                self.logger.warning("got exception when trying to transcode", exc_info=True)
+                self.logger.warning(
+                    "got exception when trying to transcode, will retry", exc_info=True
+                )
+
+            if remove:
+                queue.remove(item)
 
             sleep(3)
 
-    def _do_transcode(self, item: TranscodeItem) -> bool:
+    def transcode(self, item: TranscodeItem) -> bool:
         path = pathlib.Path(item.path)
 
         self.logger.info(f"attempting to transcode {path.name}")
@@ -82,7 +176,7 @@ class Transcoder:
 
         # duration = _get_duration(item.path)
 
-        tmp_folder = pathlib.Path("/tmp/wi1-bot")
+        tmp_folder = pathlib.Path(tempfile.gettempdir()) / "wi1-bot"
         tmp_folder.mkdir(exist_ok=True)
 
         filename = path.stem
@@ -90,7 +184,7 @@ class Transcoder:
         filename = CLEAN_TORRENT_SUFFIX_REGEX.sub("", filename)
         transcode_to = tmp_folder / f"{filename}-TRANSCODED.mkv"
 
-        command = self._build_ffmpeg_command(item, transcode_to)
+        command = build_ffmpeg_command(item, transcode_to)
 
         self.logger.debug(f"ffmpeg command: {shlex.join(command)}")
 
@@ -192,95 +286,6 @@ class Transcoder:
             ):
                 self.sonarr.rescan_series(item.content_id)
 
-    def _get_duration(self, path: str) -> timedelta:
-        probe_command = [
-            "ffprobe",
-            "-hide_banner",
-            "-show_entries",
-            "format=duration",
-            "-of",
-            "default=noprint_wrappers=1:nokey=1",
-            path,
-        ]
-
-        probe_result = subprocess.run(probe_command, capture_output=True, text=True)
-
-        try:
-            duration = timedelta(seconds=float(probe_result.stdout.strip()))
-        except ValueError:
-            raise FileNotFoundError
-
-        return duration
-
-    def _build_ffmpeg_command(self, item: TranscodeItem, transcode_to: pathlib.Path) -> list[str]:
-        command: list[Any] = [
-            "ffmpeg",
-            "-hide_banner",
-            "-y",
-        ]
-
-        if "transcoding" in config and "hwaccel" in config["transcoding"]:
-            command.extend(["-hwaccel", config["transcoding"]["hwaccel"]])
-            command.extend(["-hwaccel_output_format", config["transcoding"]["hwaccel"]])
-
-        command.extend(["-probesize", "100M"])
-        command.extend(["-analyzeduration", "250M"])
-
-        command.extend(["-i", item.path])
-
-        langs: list[str] = []
-
-        if item.languages:
-            langs = item.languages.split(",")
-
-        # TODO: use ffprobe to figure out what streams we should copy
-        # always copy first video stream
-        # always copy first audio stream
-        # always copy all subtitle streams
-        # if languages is specified in the config:
-        #     copy all audio streams in one of those languages
-        # ffprobe -show_streams -print_format json {input_file} 2>/dev/null
-        if item.copy_all_streams:
-            command.extend(["-map", "0"])
-        else:
-            command.extend(["-map", "0:v:0"])
-
-            command.extend(["-map", "0:a:0?"])
-
-            if langs:
-                command.extend([["-map", f"0:s:m:language:{lang}?"] for lang in langs])
-            else:
-                command.extend(["-map", "0:s?"])
-
-        if item.video_codec:
-            command.extend(["-vcodec", item.video_codec])
-            command.extend(["-preset", "fast"])
-            command.extend(["-profile:v", "main"])
-        else:
-            command.extend(["-vcodec", "copy"])
-
-        if item.video_bitrate:
-            command.extend(["-b:v", item.video_bitrate])
-            command.extend(["-maxrate", item.video_bitrate * 2])
-            command.extend(["-bufsize", item.video_bitrate * 2])
-
-        if item.audio_codec:
-            command.extend(["-acodec", item.audio_codec])
-        else:
-            command.extend(["-acodec", "copy"])
-
-        if item.audio_channels:
-            command.extend(["-ac", item.audio_channels])
-
-        if item.audio_bitrate:
-            command.extend(["-b:a", item.audio_bitrate])
-
-        command.extend(["-scodec", "copy"])
-
-        command.extend([transcode_to])
-
-        return [str(arg) for arg in command]
-
 
 if __name__ == "__main__":
     logging.basicConfig(level=logging.DEBUG)
