@@ -6,9 +6,10 @@ from typing import Any
 
 from flask import Flask, request
 
-from wi1_bot import push, transcoder
+from wi1_bot import push
 from wi1_bot.arr import Radarr, Sonarr, replace_remote_paths
 from wi1_bot.config import config
+from wi1_bot.transcoder.transcode_queue import queue
 
 app = Flask(__name__)
 
@@ -66,24 +67,16 @@ def on_download(req: dict[str, Any]) -> None:
 
     quality_options = config["transcoding"]["profiles"][quality_profile]
 
-    copy_all_streams = quality_options.get("copy_all_streams", None)
     languages = quality_options.get("languages", None)
-    video_codec = quality_options.get("video_codec", None)
-    video_bitrate = quality_options.get("video_bitrate", None)
-    audio_codec = quality_options.get("audio_codec", None)
-    audio_channels = quality_options.get("audio_channels", None)
-    audio_bitrate = quality_options.get("audio_bitrate", None)
+    video_params = quality_options.get("video_params", None)
+    audio_params = quality_options.get("audio_params", None)
 
-    transcoder.queue.add(
+    queue.add(
         path=str(path),
         content_id=content_id,
-        copy_all_streams=copy_all_streams,
         languages=languages,
-        video_codec=video_codec,
-        video_bitrate=video_bitrate,
-        audio_codec=audio_codec,
-        audio_channels=audio_channels,
-        audio_bitrate=audio_bitrate,
+        video_params=video_params,
+        audio_params=audio_params,
     )
 
 
